midiogre package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   midiogre.augmentations
   midiogre.core

Module contents
--------------

.. automodule:: midiogre
   :members:
   :undoc-members:
   :show-inheritance: 